@@ -1,5 +1,9 @@
+#include <Python.h>
+#if PY_VERSION_HEX >= 0x02040000
+# include <datetime.h> /* From Python */
+#endif
 #include "pygdavalue_conversions.h"
-#include <datetime.h> /* From Python */
+
 
 /**
  * pygda_value_from_pyobject:
@@ -30,6 +34,7 @@ pygda_value_from_pyobject(GdaValue *boxed, PyObject *input)
       gda_value_set_double (boxed, PyFloat_AsDouble (input));
     } else if (PyBool_Check (input)) {
       gda_value_set_boolean (boxed, (input == Py_True));
+#if PY_VERSION_HEX >= 0x02040000
     } else if (PyDateTime_Check (input)) {
          GdaTimestamp gda;
          gda.year = PyDateTime_GET_YEAR(input);
@@ -53,6 +58,7 @@ pygda_value_from_pyobject(GdaValue *boxed, PyObject *input)
          gda.second = PyDateTime_TIME_GET_SECOND(input);
          gda.timezone = 0;
          gda_value_set_time (boxed, &gda);
+#endif
     } else {
       g_warning("Unhandled python type.");
       return -1; //failed.
@@ -79,7 +85,9 @@ pygda_value_as_pyobject(const GdaValue *boxed, gboolean copy_boxed)
 
     value_type = gda_value_get_type ((GdaValue*)boxed);
 
+#if PY_VERSION_HEX >= 0x02040000
     PyDateTime_IMPORT; /* So we can use PyDate*() functions. */
+#endif
 
     if (value_type == GDA_VALUE_TYPE_NULL) {
       Py_INCREF (Py_None);
@@ -97,10 +105,12 @@ pygda_value_as_pyobject(const GdaValue *boxed, gboolean copy_boxed)
         ret = 0; /* TODO: This thing has a whole read/write API. */
     } else if (value_type == GDA_VALUE_TYPE_BOOLEAN) {
         ret = PyBool_FromLong (gda_value_get_boolean ((GdaValue*)boxed));
+#if PY_VERSION_HEX >= 0x02040000
     } else if (value_type == GDA_VALUE_TYPE_DATE) {
         const GdaDate* val = gda_value_get_date ((GdaValue*)boxed);
         if(val)
           ret = PyDate_FromDate(val->year, val->month, val->day);
+#endif
     } else if (value_type == GDA_VALUE_TYPE_DOUBLE) {
         ret = PyFloat_FromDouble (gda_value_get_double ((GdaValue*)boxed));
     } else if (value_type == GDA_VALUE_TYPE_GEOMETRIC_POINT) {
@@ -115,7 +125,7 @@ pygda_value_as_pyobject(const GdaValue *boxed, gboolean copy_boxed)
         const GdaNumeric* val = gda_value_get_numeric ((GdaValue*)boxed);
         const gchar* number_as_text = val->number; /* Formatted according to the C locale, probably. */
         /* This would need a string _object_: ret = PyFloat_FromString(number_as_text, 0); */
-        ret = PyFloat_FromDouble (PyOS_ascii_strtod (number_as_text, 0));
+        ret = PyFloat_FromDouble (g_ascii_strtod (number_as_text, NULL));
     } else if (value_type == GDA_VALUE_TYPE_SINGLE) {
         ret = PyFloat_FromDouble (gda_value_get_single ((GdaValue*)boxed));
     } else if (value_type == GDA_VALUE_TYPE_SMALLINT) {
@@ -124,11 +134,13 @@ pygda_value_as_pyobject(const GdaValue *boxed, gboolean copy_boxed)
         const gchar* val = gda_value_get_string ((GdaValue*)boxed);
         ret = PyString_FromString (val);
     } else if (value_type == GDA_VALUE_TYPE_TIME) {
+#if PY_VERSION_HEX >= 0x02040000
         const GdaTime* val = gda_value_get_time ((GdaValue*)boxed);
         ret = PyTime_FromTime(val->hour, val->minute, val->second, 0); /* TODO: Should we ignore GdaDate::timezone ? */
     } else if (value_type == GDA_VALUE_TYPE_TIMESTAMP) {
         const GdaTimestamp* val = gda_value_get_timestamp ((GdaValue*)boxed);
         ret = PyDateTime_FromDateAndTime(val->year, val->month, val->day, val->hour, val->minute, val->second, 0); /* TODO: Should we ignore GdaTimestamp::timezone ? */
+#endif
     } else if (value_type == GDA_VALUE_TYPE_TINYINT) {
         ret = PyInt_FromLong (gda_value_get_tinyint ((GdaValue*)boxed));
     } else if (value_type == GDA_VALUE_TYPE_TINYUINT) {
